summaryrefslogtreecommitdiffstats
path: root/dom/canvas/CanvasImageCache.h
diff options
context:
space:
mode:
Diffstat (limited to 'dom/canvas/CanvasImageCache.h')
-rw-r--r--dom/canvas/CanvasImageCache.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/dom/canvas/CanvasImageCache.h b/dom/canvas/CanvasImageCache.h
index 58486c5a8d..c860951fb7 100644
--- a/dom/canvas/CanvasImageCache.h
+++ b/dom/canvas/CanvasImageCache.h
@@ -12,7 +12,7 @@
namespace mozilla {
namespace dom {
class Element;
-class HTMLCanvasElement;
+class CanvasRenderingContext2D;
} // namespace dom
namespace gfx {
class DrawTarget;
@@ -28,18 +28,23 @@ class CanvasImageCache {
public:
/**
* Notify that image element aImage was drawn to aCanvas element
* using the first frame of aRequest's image. The data for the surface is
* in aSurface, and the image size is in aSize. aIntrinsicSize is the size
* the surface is intended to be rendered at.
*/
static void NotifyDrawImage(dom::Element* aImage,
- dom::HTMLCanvasElement* aCanvas,
+ dom::CanvasRenderingContext2D* aContext,
gfx::DrawTarget* aTarget, SourceSurface* aSource,
const gfx::IntSize& aSize,
const gfx::IntSize& aIntrinsicSize);
/**
+ * Notify that aContext is being destroyed.
+ */
+ static void NotifyCanvasDestroyed(dom::CanvasRenderingContext2D* aContext);
+
+ /**
* Check whether aImage has recently been drawn any canvas. If we return
* a non-null surface, then the same image was recently drawn into a canvas.
*/
@@ -47,11 +52,11 @@ class CanvasImageCache {
gfx::DrawTarget* aTarget);
/**
* Like the top above, but restricts the lookup to only aCanvas. This is
* required for CORS security.
*/
static SourceSurface* LookupCanvas(dom::Element* aImage,
- dom::HTMLCanvasElement* aCanvas,
+ dom::CanvasRenderingContext2D* aContext,
gfx::DrawTarget* aTarget,
gfx::IntSize* aSizeOut,
gfx::IntSize* aIntrinsicSizeOut);
@@ -28,18 +28,23 @@ class CanvasImageCache {
public:
/**
- * Notify that image element aImage was drawn to aCanvas element
+ * Notify that image element aImage was drawn to aContext canvas
* using the first frame of aRequest's image. The data for the surface is
* in aSurface, and the image size is in aSize. aIntrinsicSize is the size
@@ -47,11 +52,11 @@ class CanvasImageCache {
gfx::DrawTarget* aTarget);
/**
- * Like the top above, but restricts the lookup to only aCanvas. This is
+ * Like the top above, but restricts the lookup to only aContext. This is
* required for CORS security.
*/